@@ -49,9 +49,11 @@ bool cEnigmaLogoCache::DrawEventImage(const cEvent *Event, int x, int y, int w,
     return false;
 
   char *strFilename = NULL;
-  asprintf(&strFilename, "%s/%d.%s", EnigmaConfig.GetImagesDir(), Event->EventID(), EnigmaConfig.GetImageExtension());
-  int rc = DrawImage(strFilename, x, y, w, h, c, bmp);
-  free (strFilename);
+  int rc = false;
+  if (-1 != asprintf(&strFilename, "%s/%d.%s", EnigmaConfig.GetImagesDir(), Event->EventID(), EnigmaConfig.GetImageExtension())) {
+    rc = DrawImage(strFilename, x, y, w, h, c, bmp);
+    free (strFilename);
+  }
   return rc;
 }
 
@@ -61,9 +63,11 @@ bool cEnigmaLogoCache::DrawRecordingImage(const cRecording *Recording, int x, in
     return false;
 
   char *strFilename = NULL;
-  asprintf(&strFilename, "%s/%s.%s", Recording->FileName(), RECORDING_COVER, EnigmaConfig.GetImageExtension());
-  int rc = DrawImage(strFilename, x, y, w, h, c, bmp);
-  free (strFilename);
+  int rc = false;
+  if (-1 != asprintf(&strFilename, "%s/%s.%s", Recording->FileName(), RECORDING_COVER, EnigmaConfig.GetImageExtension())) {
+    rc = DrawImage(strFilename, x, y, w, h, c, bmp);
+    free (strFilename);
+  }
   return rc;
 }
 
@@ -96,24 +100,36 @@ bool cEnigmaLogoCache::LoadChannelLogo(const cChannel *Channel)
     return false;
 
   bool fFoundLogo = false;
+  const char *logoname = NULL;
+  char *strLogo = NULL;
+  char *filename = NULL;
+
   char *strChannelID = EnigmaConfig.useChannelId && !Channel->GroupSep() ? strdup(*Channel->GetChannelID().ToString()) : NULL;
-  const char *logoname = EnigmaConfig.useChannelId && !Channel->GroupSep() ? strChannelID : Channel->Name();
-  if (logoname) {
-    char *filename = (char *)malloc(strlen(logoname) + 20 /* should be enough for folder */);
-    if (filename == NULL) return false;
-    strcpy(filename, "hqlogos/");
-    strcat(filename, logoname);
+  logoname = EnigmaConfig.useChannelId && !Channel->GroupSep() ? strChannelID : Channel->Name();
+  if (logoname == NULL) goto leave;
+
+  strLogo = strreplace(strdup(logoname), '/', '~');
+  if (strLogo == NULL) goto leave;
+
+  filename = (char *)malloc(strlen(strLogo) + 20 /* should be enough for folder */);
+  if (filename == NULL) goto leave;
+
+  strcpy(filename, "hqlogos/");
+  strcat(filename, strLogo);
+  if (!(fFoundLogo = Load(filename, ChannelLogoWidth, ChannelLogoHeight, false))) {
+    strcpy(filename, "logos/");
+    strcat(filename, strLogo);
     if (!(fFoundLogo = Load(filename, ChannelLogoWidth, ChannelLogoHeight, false))) {
-      strcpy(filename, "logos/");
-      strcat(filename, logoname);
-      if (!(fFoundLogo = Load(filename, ChannelLogoWidth, ChannelLogoHeight, false))) {
-        error("cPluginSkinEnigma::LoadChannelLogo: LOGO \"%s.xpm\" NOT FOUND in %s/[hq]logos", logoname, EnigmaConfig.GetLogoDir());
-        fFoundLogo = Load("hqlogos/no_logo", ChannelLogoWidth, ChannelLogoHeight); //TODO? different default logo for channel/group?
-      }
+      error("cPluginSkinEnigma::LoadChannelLogo: LOGO \"%s.xpm\" NOT FOUND in %s/[hq]logos", strLogo, EnigmaConfig.GetLogoDir());
+      fFoundLogo = Load("hqlogos/no_logo", ChannelLogoWidth, ChannelLogoHeight); //TODO? different default logo for channel/group?
     }
-    free(filename);
-    free(strChannelID);
   }
+
+leave:
+  free(filename);
+  free(strLogo);
+  free(strChannelID);
+
   return fFoundLogo;
 }
 
@@ -132,9 +148,8 @@ bool cEnigmaLogoCache::Load(const char *fileNameP, int w, int h, bool fLogNotFou
   if (fileNameP == NULL)
     return false;
 
-  char *strFilename;
-  asprintf(&strFilename, "%s/%s.xpm", EnigmaConfig.GetLogoDir(), fileNameP);
-  if (strFilename == NULL)
+  char *strFilename = NULL;
+  if (-1 == asprintf(&strFilename, "%s/%s.xpm", EnigmaConfig.GetLogoDir(), fileNameP))
     return false;
 
   debug("cPluginSkinEnigma::Load(%s)", strFilename);
